@@ -683,11 +683,13 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                         g_hash_table_insert(tmp_hash, "day_sunset_not_realistically", g_strdup(buffer));
                                                         g_hash_table_insert(tmp_hash, "day_sunrise_not_realistically", g_strdup(temp_buffer));
                                                     }else{
-                                                        g_hash_table_insert(tmp_hash, "day_sunset", g_strdup(buffer));
-                                                        g_hash_table_insert(tmp_hash, "day_sunrise", g_strdup(temp_buffer));
-                                                        /* fprintf(stderr, "Real Sunrise %s\n", temp_buffer); 
-                                                         fprintf(stderr, "Real Sunset %s\n", buffer); 
+                                                        g_hash_table_insert(tmp_hash, "day_sunset", g_strdup(temp_buffer));
+                                                        g_hash_table_insert(tmp_hash, "day_sunrise", g_strdup(buffer));
+                                                        /*
+                                                         fprintf(stderr, "Real Sunrise %s\n", buffer); 
+                                                         fprintf(stderr, "Real Sunset %s\n", temp_buffer); 
                                                         */
+                                                        
                                                     }
 
                                                     tmp_list = g_slist_next(tmp_list);
@@ -700,9 +702,24 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                 if (child_node11)
                                                     child_node11 = child_node11->next;
                                                 if (child_node11)
-                                                    child_node11 = child_node11->next;
+                                                    child_node11 = child_node11->children;
                                                 if (child_node11)
                                                     child_node11 = child_node11->next;
+
+                                                xmlFree(temp_xml_string);
+                                                temp_xml_string = NULL;
+                                                temp_xml_string = xmlGetProp(child_node11,(const xmlChar*)"class"); 
+                                                fprintf(stderr, "\n Фаза %s\n", temp_xml_string);
+                                                if (temp_xml_string){
+                                                    if (!strncmp(temp_xml_string,"moon4",5))
+                                                        g_hash_table_insert(current_weather, "moon_phase", 
+                                                                                            g_strdup("First Quarter"));
+                                                    if (!strncmp(temp_xml_string,"moon5",5))
+                                                        g_hash_table_insert(current_weather, "moon_phase", 
+                                                                                            g_strdup("Waxing Gibbous"));
+                                                    xmlFree(temp_xml_string);
+                                                }
+/*
                                                 if(child_node11 && child_node11->name &&
                                                    !xmlStrcmp(child_node11->name, (const xmlChar *)"li")){
                                                    xmlFree(temp_xml_string);
@@ -713,6 +730,7 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                        xmlFree(temp_xml_string);
                                                     }
                                                 }
+*/
                                            }
                                        }
                                   }
@@ -834,6 +852,9 @@ fill_current_data(xmlNode *root_node, GHashTable *current_weather, GHashTable *d
                                                                  sprintf(buffer,"%s","NE");
                                                             if (!strcoll(buffer, "безветрие"))
                                                                  sprintf(buffer,"%s","CALM");
+                                                            if (!strcoll(buffer, "Ш"))
+                                                                 sprintf(buffer,"%s","CALM");
+ 
                                                             g_hash_table_insert(current_weather, "wind_direction", g_strdup(buffer));
                                                             /*Wind speed. m/s in km/h*/
                                                             speed = atoi (temp_buffer);
